==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/sql/kotlin/inputs/GetManagedDatabaseVulnerabilityAssessmentRuleBaselinePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sql.kotlin.inputs

import com.pulumi.azurenative.sql.inputs.GetManagedDatabaseVulnerabilityAssessmentRuleBaselinePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property baselineName The name of the vulnerability assessment rule baseline (default implies a baseline on a database level rule and master for server level rule).
 * @property databaseName The name of the database for which the vulnerability assessment rule baseline is defined.
 * @property managedInstanceName The name of the managed instance.
 * @property resourceGroupName The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
 * @property ruleId The vulnerability assessment rule ID.
 * @property vulnerabilityAssessmentName The name of the vulnerability assessment.
 */
public data class GetManagedDatabaseVulnerabilityAssessmentRuleBaselinePlainArgs(
    public val baselineName: String,
    public val databaseName: String,
    public val managedInstanceName: String,
    public val resourceGroupName: String,
    public val ruleId: String,
    public val vulnerabilityAssessmentName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.sql.inputs.GetManagedDatabaseVulnerabilityAssessmentRuleBaselinePlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.sql.inputs.GetManagedDatabaseVulnerabilityAssessmentRuleBaselinePlainArgs =
        com.pulumi.azurenative.sql.inputs.GetManagedDatabaseVulnerabilityAssessmentRuleBaselinePlainArgs.builder()
            .baselineName(baselineName.let({ args0 -> args0 }))
            .databaseName(databaseName.let({ args0 -> args0 }))
            .managedInstanceName(managedInstanceName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .ruleId(ruleId.let({ args0 -> args0 }))
            .vulnerabilityAssessmentName(vulnerabilityAssessmentName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetManagedDatabaseVulnerabilityAssessmentRuleBaselinePlainArgs].
 */
@PulumiTagMarker
public class GetManagedDatabaseVulnerabilityAssessmentRuleBaselinePlainArgsBuilder internal
constructor() {
    private var baselineName: String? = null

    private var databaseName: String? = null

    private var managedInstanceName: String? = null

    private var resourceGroupName: String? = null

    private var ruleId: String? = null

    private var vulnerabilityAssessmentName: String? = null

    /**
     * @param value The name of the vulnerability assessment rule baseline (default implies a baseline on a database level rule and master for server level rule).
     */
    @JvmName("vfkkkqqxowejjjtp")
    public suspend fun baselineName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.baselineName = mapped
    }

    /**
     * @param value The name of the database for which the vulnerability assessment rule baseline is defined.
     */
    @JvmName("ubdiqolamjdbugfw")
    public suspend fun databaseName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.databaseName = mapped
    }

    /**
     * @param value The name of the managed instance.
     */
    @JvmName("udkpkxacmolrqgki")
    public suspend fun managedInstanceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.managedInstanceName = mapped
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("djjekfphlhbdsrwb")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The vulnerability assessment rule ID.
     */
    @JvmName("bvaksxqlmnipfpyw")
    public suspend fun ruleId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.ruleId = mapped
    }

    /**
     * @param value The name of the vulnerability assessment.
     */
    @JvmName("akoevoxqrkmgmbvr")
    public suspend fun vulnerabilityAssessmentName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.vulnerabilityAssessmentName = mapped
    }

    internal fun build(): GetManagedDatabaseVulnerabilityAssessmentRuleBaselinePlainArgs =
        GetManagedDatabaseVulnerabilityAssessmentRuleBaselinePlainArgs(
            baselineName = baselineName ?: throw PulumiNullFieldException("baselineName"),
            databaseName = databaseName ?: throw PulumiNullFieldException("databaseName"),
            managedInstanceName = managedInstanceName ?: throw PulumiNullFieldException("managedInstanceName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            ruleId = ruleId ?: throw PulumiNullFieldException("ruleId"),
            vulnerabilityAssessmentName = vulnerabilityAssessmentName ?: throw
                PulumiNullFieldException("vulnerabilityAssessmentName"),
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/sql/kotlin/inputs/GetManagedDatabaseVulnerabilityAssessmentRuleBaselinePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sql.kotlin.inputs

import com.pulumi.azurenative.sql.inputs.GetManagedDatabaseVulnerabilityAssessmentRuleBaselinePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property baselineName The name of the vulnerability assessment rule baseline (default implies a baseline on a database level rule and master for server level rule).
 * @property databaseName The name of the database for which the vulnerability assessment rule baseline is defined.
 * @property managedInstanceName The name of the managed instance.
 * @property resourceGroupName The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
 * @property ruleId The vulnerability assessment rule ID.
 * @property vulnerabilityAssessmentName The name of the vulnerability assessment.
 */
public data class GetManagedDatabaseVulnerabilityAssessmentRuleBaselinePlainArgs(
    public val baselineName: String,
    public val databaseName: String,
    public val managedInstanceName: String,
    public val resourceGroupName: String,
    public val ruleId: String,
    public val vulnerabilityAssessmentName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.sql.inputs.GetManagedDatabaseVulnerabilityAssessmentRuleBaselinePlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.sql.inputs.GetManagedDatabaseVulnerabilityAssessmentRuleBaselinePlainArgs =
        com.pulumi.azurenative.sql.inputs.GetManagedDatabaseVulnerabilityAssessmentRuleBaselinePlainArgs.builder()
            .baselineName(baselineName.let({ args0 -> args0 }))
            .databaseName(databaseName.let({ args0 -> args0 }))
            .managedInstanceName(managedInstanceName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .ruleId(ruleId.let({ args0 -> args0 }))
            .vulnerabilityAssessmentName(vulnerabilityAssessmentName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetManagedDatabaseVulnerabilityAssessmentRuleBaselinePlainArgs].
 */
@PulumiTagMarker
public class GetManagedDatabaseVulnerabilityAssessmentRuleBaselinePlainArgsBuilder internal
constructor() {
    private var baselineName: String? = null

    private var databaseName: String? = null

    private var managedInstanceName: String? = null

    private var resourceGroupName: String? = null

    private var ruleId: String? = null

    private var vulnerabilityAssessmentName: String? = null

    /**
     * @param value The name of the vulnerability assessment rule baseline (default implies a baseline on a database level rule and master for server level rule).
     */
    @JvmName("fhyojhojqqsdhvxy")
    public suspend fun baselineName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.baselineName = mapped
    }

    /**
     * @param value The name of the database for which the vulnerability assessment rule baseline is defined.
     */
    @JvmName("rfxkgsyseobfyuvs")
    public suspend fun databaseName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.databaseName = mapped
    }

    /**
     * @param value The name of the managed instance.
     */
    @JvmName("srfmytgdeundtsws")
    public suspend fun managedInstanceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.managedInstanceName = mapped
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("atkcrpdfeilxshno")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The vulnerability assessment rule ID.
     */
    @JvmName("nvbawsufpxmveamv")
    public suspend fun ruleId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.ruleId = mapped
    }

    /**
     * @param value The name of the vulnerability assessment.
     */
    @JvmName("iutexpgpdrkqsptc")
    public suspend fun vulnerabilityAssessmentName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.vulnerabilityAssessmentName = mapped
    }

    internal fun build(): GetManagedDatabaseVulnerabilityAssessmentRuleBaselinePlainArgs =
        GetManagedDatabaseVulnerabilityAssessmentRuleBaselinePlainArgs(
            baselineName = baselineName ?: throw PulumiNullFieldException("baselineName"),
            databaseName = databaseName ?: throw PulumiNullFieldException("databaseName"),
            managedInstanceName = managedInstanceName ?: throw PulumiNullFieldException("managedInstanceName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            ruleId = ruleId ?: throw PulumiNullFieldException("ruleId"),
            vulnerabilityAssessmentName = vulnerabilityAssessmentName ?: throw
                PulumiNullFieldException("vulnerabilityAssessmentName"),
        )
}
